
__doc__ = """RandomLine."""

__version__ = '0.0.1'


import string, random
from Globals import HTMLFile, MessageDialog, Persistent

import OFS.SimpleItem
import Acquisition
import AccessControl.Role


manage_addRlForm = HTMLFile('add', globals()) 

def manage_addRl(self, id, title='', atext='', REQUEST=None):
   """Add a RandomLine to a folder."""
   self._setObject(id, RandomLine(id, title, atext))
   if REQUEST is not None:
      return self.manage_main(self, REQUEST)


class RandomLine(OFS.SimpleItem.Item, Persistent, Acquisition.Implicit, AccessControl.Role.RoleManager): 
   """RandomLine object. Stores a list of lines and its text represenatation."""

   meta_type = 'RandomLine'

   manage_options = ( # what management options are there?
      {'label': 'Edit',    'action': 'manage_main'},
      {'label': 'View',    'action': ''}, # defaults to index_html
      {'label': 'Security',   'action': 'manage_access'},
      ) 

   __ac_permissions__=( # what permissions make sense for us? 
      ('View management screens', ('manage_tabs','manage_main')),
      ('Change permissions',      ('manage_access',)          ),
      ('Change RandomLine' ,      ('manage_edit',)            ),
      ('View',                    ('index_html',)             ),
      )

   def __init__(self, id, title='', atext='', strlist=None):
      """initialise a new instance"""
      self.id = id
      self.title = title
      self.text = atext
      if strlist is None:
         self.update()
      else:
         self.strlist = strlist


   index_html = HTMLFile('view', globals()) # View Interface

   manage_main = HTMLFile('edit', globals()) # Management Interface


   def manage_edit(self, title, atext, REQUEST=None): 
      """edit it"""
      self.title = title
      self.text = atext
      self.update()

      if REQUEST is not None:
         return MessageDialog(
            title = 'Edited',
            message = "Properties for %s changed." % self.id,
            action = './manage_main',
            )


   def update(self):
      if not self.text:
         self.strlist = []
      else:
         self.strlist = string.split(self.text, '\n')


   def __call__(self):
      return random.choice(self.strlist)
